﻿namespace Parsing;

using System;
using System.Collections.Generic;
using Parsing.Schema;
using Parsing.Tokenization;

public class TextParser : TokenConverter
{
    private LineParser lineParser;
    private string[] lines;
    private bool removeEmptyEntries;

    public TextParser(InputSchema schema, string[]? delimiters = null, bool removeEmptyEntries = true) : base()
    {
        this.lineParser = new LineParser(schema, delimiters, removeEmptyEntries);
        this.lines = new string[] { };
        this.removeEmptyEntries = removeEmptyEntries;
    }

    public TextParser SetInputText(string text)
    {
        var options = StringSplitOptions.TrimEntries;
        if (removeEmptyEntries)
        {
            options = options | StringSplitOptions.RemoveEmptyEntries;
        }
        this.lines = text.Split("\n", options);
        return this;
    }

    public TextParser Parse()
    {
        foreach (var line in this.lines)
        {
            this.rawTokens.Add(this.lineParser.ParseLine(line));
        }
        return this;
    }
}
